@@ -10,22 +10,25 @@
 #'
 ptd_calculate_assurance_type <- function(.data) {
   d <- .data %>%
-    group_by(.data$f) %>%
-    slice_tail(n = 1)
+    dplyr::group_by(.data$f) %>%
+    dplyr::slice_tail(n = 1)
 
   options <- attr(.data, "options")
 
   if (is.null(options$target) || options$improvement_direction == "neutral") {
-    return(summarise(d, assurance_type = as.character(NA), .groups = "drop"))
+    return(dplyr::summarise(d, assurance_type = as.character(NA), .groups = "drop"))
   }
 
   # linting reports this is assigned by not used, so excluding line from linting as it is used
   is_increasing <- options$improvement_direction == "increase" # Exclude Linting
 
   d %>%
-    summarise(assurance_type = case_when(
-      target > upl ~ ifelse(is_increasing, "consistent_fail", "consistent_pass"),
-      target < lpl ~ ifelse(is_increasing, "consistent_pass", "consistent_fail"),
-      TRUE ~ "inconsistent"
-    ), .groups = "drop")
+    dplyr::summarise(
+      assurance_type = dplyr::case_when(
+        target > upl ~ ifelse(is_increasing, "consistent_fail", "consistent_pass"),
+        target < lpl ~ ifelse(is_increasing, "consistent_pass", "consistent_fail"),
+        TRUE ~ "inconsistent"
+      ),
+      .groups = "drop"
+    )
 }
